# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: miscellaneous.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import definitions_pb2 as definitions__pb2
from . import peers_pb2 as peers__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='miscellaneous.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13miscellaneous.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x0bpeers.proto\x1a\x15scalapb/scalapb.proto\"-\n\x0cResponseVoid:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\x83\x01\n\x0bResponseSeq\x12\x1a\n\x03seq\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05state\x18\x02 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xb6\x01\n\x0fResponseSeqDate\x12\x1a\n\x03seq\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05state\x18\x02 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\x04 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xb9\x01\n\x12ResponseSeqDateMid\x12\x1a\n\x03seq\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05state\x18\x02 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\x04 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"K\n\x0cResponseBool\x12\x1c\n\x05value\x18\x01 \x01(\x08\x42\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\x91\x05\n\x06\x43onfig\x12%\n\x0emax_group_size\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x31\n\x08\x64iscover\x18\x02 \x01(\x0b\x32\x10.dialog.DiscoverB\r\x8a\xea\x30\t\n\x07visible\x12\x43\n\x0eshare_endpoint\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12\x38\n\x0c\x63\x61lls_config\x18\x05 \x01(\x0b\x32\x13.dialog.CallsConfigB\r\x8a\xea\x30\t\n\x07visible\x12\x41\n\x13group_invite_config\x18\x06 \x01(\x0b\x32\x15.dialog.InvitesConfigB\r\x8a\xea\x30\t\n\x07visible\x12?\n\x10server_meta_info\x18\x07 \x01(\x0b\x32\x16.dialog.ServerMetaInfoB\r\x8a\xea\x30\t\n\x07visible\x12,\n\x15\x63ustom_profile_schema\x18\x08 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12:\n\rservice_peers\x18\t \x01(\x0b\x32\x14.dialog.ServicePeersB\r\x8a\xea\x30\t\n\x07visible\x12\x1f\n\nextensions\x18\x03 \x03(\x0b\x32\x0b.dialog.Any\x12(\n\x11\x63lient_keep_alive\x18\n \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12L\n\x11supported_methods\x18\x0b \x03(\x0e\x32\".dialog.SupportedServerMethodsTypeB\r\x8a\xea\x30\t\n\x07visible\x12\'\n\x10max_channel_size\x18\x0c \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"s\n\x0cServicePeers\x12!\n\x08security\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeer\x12 \n\x07support\x18\x02 \x01(\x0b\x32\x0f.dialog.OutPeer\x12\x1e\n\x05stash\x18\x03 \x01(\x0b\x32\x0f.dialog.OutPeer\"v\n\x0eServerMetaInfo\x12#\n\x0crelease_date\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12?\n\x0b\x61pi_version\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\x8a\xea\x30\t\n\x07visible\"\x81\x04\n\x0b\x43\x61llsConfig\x12@\n\rcalls_enabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12\x46\n\x13video_calls_enabled\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12\x46\n\x13group_calls_enabled\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12K\n\x17group_calls_max_members\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\x12=\n\x0frtcp_mux_policy\x18\x05 \x01(\x0e\x32\x15.dialog.RtcpMuxPolicyB\r\x8a\xea\x30\t\n\x07visible\x12I\n\x16\x65moji_security_enabled\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12I\n\x16screen_sharing_enabled\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\"\xac\x02\n\rInvitesConfig\x12=\n\x08\x62\x61se_url\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12L\n\x17group_invite_url_prefix\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12G\n\x12resolve_url_prefix\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12\x45\n\x10share_invite_url\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\"9\n\x08\x44iscover\x12-\n\x05peers\x18\x01 \x03(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\"C\n\tExtension\x12\x19\n\x02id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible\"B\n\x03\x41ny\x12\x1f\n\x08type_url\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x42\x0c\x8a\xea\x30\x08\n\x06hidden\"~\n\x0cUpdateConfig\x12-\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0e.dialog.ConfigB\r\x8a\xea\x30\t\n\x07visible\x12?\n\x0b\x63onfig_hash\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\x8a\xea\x30\t\n\x07visible\"\xa0\x04\n\x11RecursiveMapValue\x12<\n\x05items\x18\x01 \x03(\x0b\x32\x1e.dialog.RecursiveMapValue.ItemB\r\x8a\xea\x30\t\n\x07visible\x1a\xa0\x02\n\x05Value\x12)\n\x01\x64\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueH\x00\x12*\n\x03i32\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueH\x00\x12*\n\x03i64\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x00\x12+\n\x03str\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12(\n\x03rec\x18\x06 \x01(\x0b\x32\x19.dialog.RecursiveMapValueH\x00\x12\x34\n\tarray_rec\x18\x07 \x01(\x0b\x32\x1f.dialog.RecursiveMapValue.ArrayH\x00\x42\x07\n\x05value\x1aG\n\x05\x41rray\x12>\n\x06values\x18\x01 \x03(\x0b\x32\x1f.dialog.RecursiveMapValue.ValueB\r\x8a\xea\x30\t\n\x07visible\x1a\x61\n\x04Item\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12=\n\x05value\x18\x02 \x01(\x0b\x32\x1f.dialog.RecursiveMapValue.ValueB\r\x8a\xea\x30\t\n\x07visible*M\n\x1aSupportedServerMethodsType\x12\x1a\n\x16NONE_SUPPORTED_METHODS\x10\x00\x12\x13\n\x0f\x43HANGE_PASSWORD\x10\x01*b\n\rRtcpMuxPolicy\x12\x19\n\x15RTCPMUXPOLICY_UNKNOWN\x10\x00\x12\x1b\n\x17RTCPMUXPOLICY_NEGOTIATE\x10\x01\x12\x19\n\x15RTCPMUXPOLICY_REQUIRE\x10\x02*[\n\x12UpdateOptimization\x12\x1e\n\x1aUPDATEOPTIMIZATION_UNKNOWN\x10\x00\x12%\n!UPDATEOPTIMIZATION_STRIP_ENTITIES\x10\x02\x42\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])

_SUPPORTEDSERVERMETHODSTYPE = _descriptor.EnumDescriptor(
  name='SupportedServerMethodsType',
  full_name='dialog.SupportedServerMethodsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE_SUPPORTED_METHODS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_PASSWORD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3336,
  serialized_end=3413,
)
_sym_db.RegisterEnumDescriptor(_SUPPORTEDSERVERMETHODSTYPE)

SupportedServerMethodsType = enum_type_wrapper.EnumTypeWrapper(_SUPPORTEDSERVERMETHODSTYPE)
_RTCPMUXPOLICY = _descriptor.EnumDescriptor(
  name='RtcpMuxPolicy',
  full_name='dialog.RtcpMuxPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RTCPMUXPOLICY_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RTCPMUXPOLICY_NEGOTIATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RTCPMUXPOLICY_REQUIRE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3415,
  serialized_end=3513,
)
_sym_db.RegisterEnumDescriptor(_RTCPMUXPOLICY)

RtcpMuxPolicy = enum_type_wrapper.EnumTypeWrapper(_RTCPMUXPOLICY)
_UPDATEOPTIMIZATION = _descriptor.EnumDescriptor(
  name='UpdateOptimization',
  full_name='dialog.UpdateOptimization',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UPDATEOPTIMIZATION_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATEOPTIMIZATION_STRIP_ENTITIES', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3515,
  serialized_end=3606,
)
_sym_db.RegisterEnumDescriptor(_UPDATEOPTIMIZATION)

UpdateOptimization = enum_type_wrapper.EnumTypeWrapper(_UPDATEOPTIMIZATION)
NONE_SUPPORTED_METHODS = 0
CHANGE_PASSWORD = 1
RTCPMUXPOLICY_UNKNOWN = 0
RTCPMUXPOLICY_NEGOTIATE = 1
RTCPMUXPOLICY_REQUIRE = 2
UPDATEOPTIMIZATION_UNKNOWN = 0
UPDATEOPTIMIZATION_STRIP_ENTITIES = 2



_RESPONSEVOID = _descriptor.Descriptor(
  name='ResponseVoid',
  full_name='dialog.ResponseVoid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=163,
)


_RESPONSESEQ = _descriptor.Descriptor(
  name='ResponseSeq',
  full_name='dialog.ResponseSeq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseSeq.seq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseSeq.state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.ResponseSeq.date', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=297,
)


_RESPONSESEQDATE = _descriptor.Descriptor(
  name='ResponseSeqDate',
  full_name='dialog.ResponseSeqDate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseSeqDate.seq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseSeqDate.state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.ResponseSeqDate.date', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.ResponseSeqDate.mid', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=482,
)


_RESPONSESEQDATEMID = _descriptor.Descriptor(
  name='ResponseSeqDateMid',
  full_name='dialog.ResponseSeqDateMid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseSeqDateMid.seq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseSeqDateMid.state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.ResponseSeqDateMid.date', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.ResponseSeqDateMid.mid', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=485,
  serialized_end=670,
)


_RESPONSEBOOL = _descriptor.Descriptor(
  name='ResponseBool',
  full_name='dialog.ResponseBool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.ResponseBool.value', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=747,
)


_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='dialog.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_group_size', full_name='dialog.Config.max_group_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discover', full_name='dialog.Config.discover', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='share_endpoint', full_name='dialog.Config.share_endpoint', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calls_config', full_name='dialog.Config.calls_config', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_invite_config', full_name='dialog.Config.group_invite_config', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_meta_info', full_name='dialog.Config.server_meta_info', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_profile_schema', full_name='dialog.Config.custom_profile_schema', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_peers', full_name='dialog.Config.service_peers', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extensions', full_name='dialog.Config.extensions', index=8,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_keep_alive', full_name='dialog.Config.client_keep_alive', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported_methods', full_name='dialog.Config.supported_methods', index=10,
      number=11, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_channel_size', full_name='dialog.Config.max_channel_size', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=750,
  serialized_end=1407,
)


_SERVICEPEERS = _descriptor.Descriptor(
  name='ServicePeers',
  full_name='dialog.ServicePeers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='security', full_name='dialog.ServicePeers.security', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='support', full_name='dialog.ServicePeers.support', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stash', full_name='dialog.ServicePeers.stash', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1409,
  serialized_end=1524,
)


_SERVERMETAINFO = _descriptor.Descriptor(
  name='ServerMetaInfo',
  full_name='dialog.ServerMetaInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='release_date', full_name='dialog.ServerMetaInfo.release_date', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='api_version', full_name='dialog.ServerMetaInfo.api_version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1526,
  serialized_end=1644,
)


_CALLSCONFIG = _descriptor.Descriptor(
  name='CallsConfig',
  full_name='dialog.CallsConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='calls_enabled', full_name='dialog.CallsConfig.calls_enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='video_calls_enabled', full_name='dialog.CallsConfig.video_calls_enabled', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_calls_enabled', full_name='dialog.CallsConfig.group_calls_enabled', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_calls_max_members', full_name='dialog.CallsConfig.group_calls_max_members', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtcp_mux_policy', full_name='dialog.CallsConfig.rtcp_mux_policy', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emoji_security_enabled', full_name='dialog.CallsConfig.emoji_security_enabled', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='screen_sharing_enabled', full_name='dialog.CallsConfig.screen_sharing_enabled', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1647,
  serialized_end=2160,
)


_INVITESCONFIG = _descriptor.Descriptor(
  name='InvitesConfig',
  full_name='dialog.InvitesConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_url', full_name='dialog.InvitesConfig.base_url', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_invite_url_prefix', full_name='dialog.InvitesConfig.group_invite_url_prefix', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_url_prefix', full_name='dialog.InvitesConfig.resolve_url_prefix', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='share_invite_url', full_name='dialog.InvitesConfig.share_invite_url', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2163,
  serialized_end=2463,
)


_DISCOVER = _descriptor.Descriptor(
  name='Discover',
  full_name='dialog.Discover',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peers', full_name='dialog.Discover.peers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2465,
  serialized_end=2522,
)


_EXTENSION = _descriptor.Descriptor(
  name='Extension',
  full_name='dialog.Extension',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.Extension.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='dialog.Extension.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2524,
  serialized_end=2591,
)


_ANY = _descriptor.Descriptor(
  name='Any',
  full_name='dialog.Any',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type_url', full_name='dialog.Any.type_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='dialog.Any.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2593,
  serialized_end=2659,
)


_UPDATECONFIG = _descriptor.Descriptor(
  name='UpdateConfig',
  full_name='dialog.UpdateConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='dialog.UpdateConfig.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_hash', full_name='dialog.UpdateConfig.config_hash', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2661,
  serialized_end=2787,
)


_RECURSIVEMAPVALUE_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='dialog.RecursiveMapValue.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='d', full_name='dialog.RecursiveMapValue.Value.d', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i32', full_name='dialog.RecursiveMapValue.Value.i32', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i64', full_name='dialog.RecursiveMapValue.Value.i64', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='str', full_name='dialog.RecursiveMapValue.Value.str', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rec', full_name='dialog.RecursiveMapValue.Value.rec', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_rec', full_name='dialog.RecursiveMapValue.Value.array_rec', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='dialog.RecursiveMapValue.Value.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2874,
  serialized_end=3162,
)

_RECURSIVEMAPVALUE_ARRAY = _descriptor.Descriptor(
  name='Array',
  full_name='dialog.RecursiveMapValue.Array',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='dialog.RecursiveMapValue.Array.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3164,
  serialized_end=3235,
)

_RECURSIVEMAPVALUE_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='dialog.RecursiveMapValue.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.RecursiveMapValue.Item.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.RecursiveMapValue.Item.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3237,
  serialized_end=3334,
)

_RECURSIVEMAPVALUE = _descriptor.Descriptor(
  name='RecursiveMapValue',
  full_name='dialog.RecursiveMapValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='dialog.RecursiveMapValue.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RECURSIVEMAPVALUE_VALUE, _RECURSIVEMAPVALUE_ARRAY, _RECURSIVEMAPVALUE_ITEM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2790,
  serialized_end=3334,
)

_RESPONSESEQDATE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_RESPONSESEQDATEMID.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_CONFIG.fields_by_name['discover'].message_type = _DISCOVER
_CONFIG.fields_by_name['share_endpoint'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONFIG.fields_by_name['calls_config'].message_type = _CALLSCONFIG
_CONFIG.fields_by_name['group_invite_config'].message_type = _INVITESCONFIG
_CONFIG.fields_by_name['server_meta_info'].message_type = _SERVERMETAINFO
_CONFIG.fields_by_name['service_peers'].message_type = _SERVICEPEERS
_CONFIG.fields_by_name['extensions'].message_type = _ANY
_CONFIG.fields_by_name['supported_methods'].enum_type = _SUPPORTEDSERVERMETHODSTYPE
_SERVICEPEERS.fields_by_name['security'].message_type = peers__pb2._OUTPEER
_SERVICEPEERS.fields_by_name['support'].message_type = peers__pb2._OUTPEER
_SERVICEPEERS.fields_by_name['stash'].message_type = peers__pb2._OUTPEER
_SERVERMETAINFO.fields_by_name['api_version'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CALLSCONFIG.fields_by_name['calls_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLSCONFIG.fields_by_name['video_calls_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLSCONFIG.fields_by_name['group_calls_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLSCONFIG.fields_by_name['group_calls_max_members'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_CALLSCONFIG.fields_by_name['rtcp_mux_policy'].enum_type = _RTCPMUXPOLICY
_CALLSCONFIG.fields_by_name['emoji_security_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLSCONFIG.fields_by_name['screen_sharing_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_INVITESCONFIG.fields_by_name['base_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVITESCONFIG.fields_by_name['group_invite_url_prefix'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVITESCONFIG.fields_by_name['resolve_url_prefix'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVITESCONFIG.fields_by_name['share_invite_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DISCOVER.fields_by_name['peers'].message_type = peers__pb2._OUTPEER
_UPDATECONFIG.fields_by_name['config'].message_type = _CONFIG
_UPDATECONFIG.fields_by_name['config_hash'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_RECURSIVEMAPVALUE_VALUE.fields_by_name['d'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_RECURSIVEMAPVALUE_VALUE.fields_by_name['i32'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_RECURSIVEMAPVALUE_VALUE.fields_by_name['i64'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_RECURSIVEMAPVALUE_VALUE.fields_by_name['str'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECURSIVEMAPVALUE_VALUE.fields_by_name['rec'].message_type = _RECURSIVEMAPVALUE
_RECURSIVEMAPVALUE_VALUE.fields_by_name['array_rec'].message_type = _RECURSIVEMAPVALUE_ARRAY
_RECURSIVEMAPVALUE_VALUE.containing_type = _RECURSIVEMAPVALUE
_RECURSIVEMAPVALUE_VALUE.oneofs_by_name['value'].fields.append(
  _RECURSIVEMAPVALUE_VALUE.fields_by_name['d'])
_RECURSIVEMAPVALUE_VALUE.fields_by_name['d'].containing_oneof = _RECURSIVEMAPVALUE_VALUE.oneofs_by_name['value']
_RECURSIVEMAPVALUE_VALUE.oneofs_by_name['value'].fields.append(
  _RECURSIVEMAPVALUE_VALUE.fields_by_name['i32'])
_RECURSIVEMAPVALUE_VALUE.fields_by_name['i32'].containing_oneof = _RECURSIVEMAPVALUE_VALUE.oneofs_by_name['value']
_RECURSIVEMAPVALUE_VALUE.oneofs_by_name['value'].fields.append(
  _RECURSIVEMAPVALUE_VALUE.fields_by_name['i64'])
_RECURSIVEMAPVALUE_VALUE.fields_by_name['i64'].containing_oneof = _RECURSIVEMAPVALUE_VALUE.oneofs_by_name['value']
_RECURSIVEMAPVALUE_VALUE.oneofs_by_name['value'].fields.append(
  _RECURSIVEMAPVALUE_VALUE.fields_by_name['str'])
_RECURSIVEMAPVALUE_VALUE.fields_by_name['str'].containing_oneof = _RECURSIVEMAPVALUE_VALUE.oneofs_by_name['value']
_RECURSIVEMAPVALUE_VALUE.oneofs_by_name['value'].fields.append(
  _RECURSIVEMAPVALUE_VALUE.fields_by_name['rec'])
_RECURSIVEMAPVALUE_VALUE.fields_by_name['rec'].containing_oneof = _RECURSIVEMAPVALUE_VALUE.oneofs_by_name['value']
_RECURSIVEMAPVALUE_VALUE.oneofs_by_name['value'].fields.append(
  _RECURSIVEMAPVALUE_VALUE.fields_by_name['array_rec'])
_RECURSIVEMAPVALUE_VALUE.fields_by_name['array_rec'].containing_oneof = _RECURSIVEMAPVALUE_VALUE.oneofs_by_name['value']
_RECURSIVEMAPVALUE_ARRAY.fields_by_name['values'].message_type = _RECURSIVEMAPVALUE_VALUE
_RECURSIVEMAPVALUE_ARRAY.containing_type = _RECURSIVEMAPVALUE
_RECURSIVEMAPVALUE_ITEM.fields_by_name['value'].message_type = _RECURSIVEMAPVALUE_VALUE
_RECURSIVEMAPVALUE_ITEM.containing_type = _RECURSIVEMAPVALUE
_RECURSIVEMAPVALUE.fields_by_name['items'].message_type = _RECURSIVEMAPVALUE_ITEM
DESCRIPTOR.message_types_by_name['ResponseVoid'] = _RESPONSEVOID
DESCRIPTOR.message_types_by_name['ResponseSeq'] = _RESPONSESEQ
DESCRIPTOR.message_types_by_name['ResponseSeqDate'] = _RESPONSESEQDATE
DESCRIPTOR.message_types_by_name['ResponseSeqDateMid'] = _RESPONSESEQDATEMID
DESCRIPTOR.message_types_by_name['ResponseBool'] = _RESPONSEBOOL
DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
DESCRIPTOR.message_types_by_name['ServicePeers'] = _SERVICEPEERS
DESCRIPTOR.message_types_by_name['ServerMetaInfo'] = _SERVERMETAINFO
DESCRIPTOR.message_types_by_name['CallsConfig'] = _CALLSCONFIG
DESCRIPTOR.message_types_by_name['InvitesConfig'] = _INVITESCONFIG
DESCRIPTOR.message_types_by_name['Discover'] = _DISCOVER
DESCRIPTOR.message_types_by_name['Extension'] = _EXTENSION
DESCRIPTOR.message_types_by_name['Any'] = _ANY
DESCRIPTOR.message_types_by_name['UpdateConfig'] = _UPDATECONFIG
DESCRIPTOR.message_types_by_name['RecursiveMapValue'] = _RECURSIVEMAPVALUE
DESCRIPTOR.enum_types_by_name['SupportedServerMethodsType'] = _SUPPORTEDSERVERMETHODSTYPE
DESCRIPTOR.enum_types_by_name['RtcpMuxPolicy'] = _RTCPMUXPOLICY
DESCRIPTOR.enum_types_by_name['UpdateOptimization'] = _UPDATEOPTIMIZATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ResponseVoid = _reflection.GeneratedProtocolMessageType('ResponseVoid', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEVOID,
  '__module__' : 'miscellaneous_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseVoid)
  })
_sym_db.RegisterMessage(ResponseVoid)

ResponseSeq = _reflection.GeneratedProtocolMessageType('ResponseSeq', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSESEQ,
  '__module__' : 'miscellaneous_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseSeq)
  })
_sym_db.RegisterMessage(ResponseSeq)

ResponseSeqDate = _reflection.GeneratedProtocolMessageType('ResponseSeqDate', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSESEQDATE,
  '__module__' : 'miscellaneous_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseSeqDate)
  })
_sym_db.RegisterMessage(ResponseSeqDate)

ResponseSeqDateMid = _reflection.GeneratedProtocolMessageType('ResponseSeqDateMid', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSESEQDATEMID,
  '__module__' : 'miscellaneous_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseSeqDateMid)
  })
_sym_db.RegisterMessage(ResponseSeqDateMid)

ResponseBool = _reflection.GeneratedProtocolMessageType('ResponseBool', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEBOOL,
  '__module__' : 'miscellaneous_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseBool)
  })
_sym_db.RegisterMessage(ResponseBool)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'miscellaneous_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Config)
  })
_sym_db.RegisterMessage(Config)

ServicePeers = _reflection.GeneratedProtocolMessageType('ServicePeers', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEPEERS,
  '__module__' : 'miscellaneous_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServicePeers)
  })
_sym_db.RegisterMessage(ServicePeers)

ServerMetaInfo = _reflection.GeneratedProtocolMessageType('ServerMetaInfo', (_message.Message,), {
  'DESCRIPTOR' : _SERVERMETAINFO,
  '__module__' : 'miscellaneous_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServerMetaInfo)
  })
_sym_db.RegisterMessage(ServerMetaInfo)

CallsConfig = _reflection.GeneratedProtocolMessageType('CallsConfig', (_message.Message,), {
  'DESCRIPTOR' : _CALLSCONFIG,
  '__module__' : 'miscellaneous_pb2'
  # @@protoc_insertion_point(class_scope:dialog.CallsConfig)
  })
_sym_db.RegisterMessage(CallsConfig)

InvitesConfig = _reflection.GeneratedProtocolMessageType('InvitesConfig', (_message.Message,), {
  'DESCRIPTOR' : _INVITESCONFIG,
  '__module__' : 'miscellaneous_pb2'
  # @@protoc_insertion_point(class_scope:dialog.InvitesConfig)
  })
_sym_db.RegisterMessage(InvitesConfig)

Discover = _reflection.GeneratedProtocolMessageType('Discover', (_message.Message,), {
  'DESCRIPTOR' : _DISCOVER,
  '__module__' : 'miscellaneous_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Discover)
  })
_sym_db.RegisterMessage(Discover)

Extension = _reflection.GeneratedProtocolMessageType('Extension', (_message.Message,), {
  'DESCRIPTOR' : _EXTENSION,
  '__module__' : 'miscellaneous_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Extension)
  })
_sym_db.RegisterMessage(Extension)

Any = _reflection.GeneratedProtocolMessageType('Any', (_message.Message,), {
  'DESCRIPTOR' : _ANY,
  '__module__' : 'miscellaneous_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Any)
  })
_sym_db.RegisterMessage(Any)

UpdateConfig = _reflection.GeneratedProtocolMessageType('UpdateConfig', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONFIG,
  '__module__' : 'miscellaneous_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateConfig)
  })
_sym_db.RegisterMessage(UpdateConfig)

RecursiveMapValue = _reflection.GeneratedProtocolMessageType('RecursiveMapValue', (_message.Message,), {

  'Value' : _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
    'DESCRIPTOR' : _RECURSIVEMAPVALUE_VALUE,
    '__module__' : 'miscellaneous_pb2'
    # @@protoc_insertion_point(class_scope:dialog.RecursiveMapValue.Value)
    })
  ,

  'Array' : _reflection.GeneratedProtocolMessageType('Array', (_message.Message,), {
    'DESCRIPTOR' : _RECURSIVEMAPVALUE_ARRAY,
    '__module__' : 'miscellaneous_pb2'
    # @@protoc_insertion_point(class_scope:dialog.RecursiveMapValue.Array)
    })
  ,

  'Item' : _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), {
    'DESCRIPTOR' : _RECURSIVEMAPVALUE_ITEM,
    '__module__' : 'miscellaneous_pb2'
    # @@protoc_insertion_point(class_scope:dialog.RecursiveMapValue.Item)
    })
  ,
  'DESCRIPTOR' : _RECURSIVEMAPVALUE,
  '__module__' : 'miscellaneous_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RecursiveMapValue)
  })
_sym_db.RegisterMessage(RecursiveMapValue)
_sym_db.RegisterMessage(RecursiveMapValue.Value)
_sym_db.RegisterMessage(RecursiveMapValue.Array)
_sym_db.RegisterMessage(RecursiveMapValue.Item)


DESCRIPTOR._options = None
_RESPONSEVOID._options = None
_RESPONSESEQ.fields_by_name['seq']._options = None
_RESPONSESEQ.fields_by_name['state']._options = None
_RESPONSESEQ.fields_by_name['date']._options = None
_RESPONSESEQ._options = None
_RESPONSESEQDATE.fields_by_name['seq']._options = None
_RESPONSESEQDATE.fields_by_name['state']._options = None
_RESPONSESEQDATE.fields_by_name['date']._options = None
_RESPONSESEQDATE.fields_by_name['mid']._options = None
_RESPONSESEQDATE._options = None
_RESPONSESEQDATEMID.fields_by_name['seq']._options = None
_RESPONSESEQDATEMID.fields_by_name['state']._options = None
_RESPONSESEQDATEMID.fields_by_name['date']._options = None
_RESPONSESEQDATEMID.fields_by_name['mid']._options = None
_RESPONSESEQDATEMID._options = None
_RESPONSEBOOL.fields_by_name['value']._options = None
_RESPONSEBOOL._options = None
_CONFIG.fields_by_name['max_group_size']._options = None
_CONFIG.fields_by_name['discover']._options = None
_CONFIG.fields_by_name['share_endpoint']._options = None
_CONFIG.fields_by_name['calls_config']._options = None
_CONFIG.fields_by_name['group_invite_config']._options = None
_CONFIG.fields_by_name['server_meta_info']._options = None
_CONFIG.fields_by_name['custom_profile_schema']._options = None
_CONFIG.fields_by_name['service_peers']._options = None
_CONFIG.fields_by_name['client_keep_alive']._options = None
_CONFIG.fields_by_name['supported_methods']._options = None
_CONFIG.fields_by_name['max_channel_size']._options = None
_SERVERMETAINFO.fields_by_name['release_date']._options = None
_SERVERMETAINFO.fields_by_name['api_version']._options = None
_CALLSCONFIG.fields_by_name['calls_enabled']._options = None
_CALLSCONFIG.fields_by_name['video_calls_enabled']._options = None
_CALLSCONFIG.fields_by_name['group_calls_enabled']._options = None
_CALLSCONFIG.fields_by_name['group_calls_max_members']._options = None
_CALLSCONFIG.fields_by_name['rtcp_mux_policy']._options = None
_CALLSCONFIG.fields_by_name['emoji_security_enabled']._options = None
_CALLSCONFIG.fields_by_name['screen_sharing_enabled']._options = None
_INVITESCONFIG.fields_by_name['base_url']._options = None
_INVITESCONFIG.fields_by_name['group_invite_url_prefix']._options = None
_INVITESCONFIG.fields_by_name['resolve_url_prefix']._options = None
_INVITESCONFIG.fields_by_name['share_invite_url']._options = None
_DISCOVER.fields_by_name['peers']._options = None
_EXTENSION.fields_by_name['id']._options = None
_EXTENSION.fields_by_name['data']._options = None
_ANY.fields_by_name['type_url']._options = None
_ANY.fields_by_name['data']._options = None
_UPDATECONFIG.fields_by_name['config']._options = None
_UPDATECONFIG.fields_by_name['config_hash']._options = None
_RECURSIVEMAPVALUE_ARRAY.fields_by_name['values']._options = None
_RECURSIVEMAPVALUE_ITEM.fields_by_name['key']._options = None
_RECURSIVEMAPVALUE_ITEM.fields_by_name['value']._options = None
_RECURSIVEMAPVALUE.fields_by_name['items']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: event_bus.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import peers_pb2 as peers__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='event_bus.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0f\x65vent_bus.proto\x12\x06\x64ialog\x1a\x1cgoogle/api/annotations.proto\x1a\x0bpeers.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x15scalapb/scalapb.proto\"n\n\x13RequestJoinEventBus\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07timeout\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"H\n\x14ResponseJoinEventBus\x12\x11\n\tdevice_id\x18\x01 \x01(\x03:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"s\n\x18RequestKeepAliveEventBus\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07timeout\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x94\x01\n\x15RequestPostToEventBus\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12#\n\x0c\x64\x65stinations\x18\x02 \x03(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1d\n\x07message\x18\x03 \x01(\x0c\x42\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xa7\x01\n\x1dUpdateEventBusDeviceConnected\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07user_id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tdevice_id\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12)\n\x04peer\x18\x04 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\"\xaa\x01\n UpdateEventBusDeviceDisconnected\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07user_id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tdevice_id\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12)\n\x04peer\x18\x04 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\"\x9c\x01\n\x15UpdateEventBusMessage\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12 \n\tsender_id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\'\n\x10sender_device_id\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1d\n\x07message\x18\x04 \x01(\x0c\x42\x0c\x8a\xea\x30\x08\n\x06hidden\"3\n\x16UpdateEventBusDisposed\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible2\xf1\x02\n\x08\x45ventBus\x12t\n\x0cJoinEventBus\x12\x1b.dialog.RequestJoinEventBus\x1a\x1c.dialog.ResponseJoinEventBus\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/grpc/EventBus/JoinEventBus:\x01*\x12{\n\x11KeepAliveEventBus\x12 .dialog.RequestKeepAliveEventBus\x1a\x14.dialog.ResponseVoid\".\x82\xd3\xe4\x93\x02(\"#/v1/grpc/EventBus/KeepAliveEventBus:\x01*\x12r\n\x0ePostToEventBus\x12\x1d.dialog.RequestPostToEventBus\x1a\x14.dialog.ResponseVoid\"+\x82\xd3\xe4\x93\x02%\" /v1/grpc/EventBus/PostToEventBus:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_REQUESTJOINEVENTBUS = _descriptor.Descriptor(
  name='RequestJoinEventBus',
  full_name='dialog.RequestJoinEventBus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestJoinEventBus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='dialog.RequestJoinEventBus.timeout', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=243,
)


_RESPONSEJOINEVENTBUS = _descriptor.Descriptor(
  name='ResponseJoinEventBus',
  full_name='dialog.ResponseJoinEventBus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='dialog.ResponseJoinEventBus.device_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=317,
)


_REQUESTKEEPALIVEEVENTBUS = _descriptor.Descriptor(
  name='RequestKeepAliveEventBus',
  full_name='dialog.RequestKeepAliveEventBus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestKeepAliveEventBus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='dialog.RequestKeepAliveEventBus.timeout', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=319,
  serialized_end=434,
)


_REQUESTPOSTTOEVENTBUS = _descriptor.Descriptor(
  name='RequestPostToEventBus',
  full_name='dialog.RequestPostToEventBus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestPostToEventBus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destinations', full_name='dialog.RequestPostToEventBus.destinations', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='dialog.RequestPostToEventBus.message', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=437,
  serialized_end=585,
)


_UPDATEEVENTBUSDEVICECONNECTED = _descriptor.Descriptor(
  name='UpdateEventBusDeviceConnected',
  full_name='dialog.UpdateEventBusDeviceConnected',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.UpdateEventBusDeviceConnected.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.UpdateEventBusDeviceConnected.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='dialog.UpdateEventBusDeviceConnected.device_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateEventBusDeviceConnected.peer', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=755,
)


_UPDATEEVENTBUSDEVICEDISCONNECTED = _descriptor.Descriptor(
  name='UpdateEventBusDeviceDisconnected',
  full_name='dialog.UpdateEventBusDeviceDisconnected',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.UpdateEventBusDeviceDisconnected.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.UpdateEventBusDeviceDisconnected.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='dialog.UpdateEventBusDeviceDisconnected.device_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateEventBusDeviceDisconnected.peer', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=758,
  serialized_end=928,
)


_UPDATEEVENTBUSMESSAGE = _descriptor.Descriptor(
  name='UpdateEventBusMessage',
  full_name='dialog.UpdateEventBusMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.UpdateEventBusMessage.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='dialog.UpdateEventBusMessage.sender_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender_device_id', full_name='dialog.UpdateEventBusMessage.sender_device_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='dialog.UpdateEventBusMessage.message', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=931,
  serialized_end=1087,
)


_UPDATEEVENTBUSDISPOSED = _descriptor.Descriptor(
  name='UpdateEventBusDisposed',
  full_name='dialog.UpdateEventBusDisposed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.UpdateEventBusDisposed.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1089,
  serialized_end=1140,
)

_UPDATEEVENTBUSDEVICECONNECTED.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEEVENTBUSDEVICEDISCONNECTED.fields_by_name['peer'].message_type = peers__pb2._PEER
DESCRIPTOR.message_types_by_name['RequestJoinEventBus'] = _REQUESTJOINEVENTBUS
DESCRIPTOR.message_types_by_name['ResponseJoinEventBus'] = _RESPONSEJOINEVENTBUS
DESCRIPTOR.message_types_by_name['RequestKeepAliveEventBus'] = _REQUESTKEEPALIVEEVENTBUS
DESCRIPTOR.message_types_by_name['RequestPostToEventBus'] = _REQUESTPOSTTOEVENTBUS
DESCRIPTOR.message_types_by_name['UpdateEventBusDeviceConnected'] = _UPDATEEVENTBUSDEVICECONNECTED
DESCRIPTOR.message_types_by_name['UpdateEventBusDeviceDisconnected'] = _UPDATEEVENTBUSDEVICEDISCONNECTED
DESCRIPTOR.message_types_by_name['UpdateEventBusMessage'] = _UPDATEEVENTBUSMESSAGE
DESCRIPTOR.message_types_by_name['UpdateEventBusDisposed'] = _UPDATEEVENTBUSDISPOSED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestJoinEventBus = _reflection.GeneratedProtocolMessageType('RequestJoinEventBus', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTJOINEVENTBUS,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestJoinEventBus)
  })
_sym_db.RegisterMessage(RequestJoinEventBus)

ResponseJoinEventBus = _reflection.GeneratedProtocolMessageType('ResponseJoinEventBus', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEJOINEVENTBUS,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseJoinEventBus)
  })
_sym_db.RegisterMessage(ResponseJoinEventBus)

RequestKeepAliveEventBus = _reflection.GeneratedProtocolMessageType('RequestKeepAliveEventBus', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTKEEPALIVEEVENTBUS,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestKeepAliveEventBus)
  })
_sym_db.RegisterMessage(RequestKeepAliveEventBus)

RequestPostToEventBus = _reflection.GeneratedProtocolMessageType('RequestPostToEventBus', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTPOSTTOEVENTBUS,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestPostToEventBus)
  })
_sym_db.RegisterMessage(RequestPostToEventBus)

UpdateEventBusDeviceConnected = _reflection.GeneratedProtocolMessageType('UpdateEventBusDeviceConnected', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENTBUSDEVICECONNECTED,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateEventBusDeviceConnected)
  })
_sym_db.RegisterMessage(UpdateEventBusDeviceConnected)

UpdateEventBusDeviceDisconnected = _reflection.GeneratedProtocolMessageType('UpdateEventBusDeviceDisconnected', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENTBUSDEVICEDISCONNECTED,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateEventBusDeviceDisconnected)
  })
_sym_db.RegisterMessage(UpdateEventBusDeviceDisconnected)

UpdateEventBusMessage = _reflection.GeneratedProtocolMessageType('UpdateEventBusMessage', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENTBUSMESSAGE,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateEventBusMessage)
  })
_sym_db.RegisterMessage(UpdateEventBusMessage)

UpdateEventBusDisposed = _reflection.GeneratedProtocolMessageType('UpdateEventBusDisposed', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENTBUSDISPOSED,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateEventBusDisposed)
  })
_sym_db.RegisterMessage(UpdateEventBusDisposed)


DESCRIPTOR._options = None
_REQUESTJOINEVENTBUS.fields_by_name['id']._options = None
_REQUESTJOINEVENTBUS.fields_by_name['timeout']._options = None
_REQUESTJOINEVENTBUS._options = None
_RESPONSEJOINEVENTBUS._options = None
_REQUESTKEEPALIVEEVENTBUS.fields_by_name['id']._options = None
_REQUESTKEEPALIVEEVENTBUS.fields_by_name['timeout']._options = None
_REQUESTKEEPALIVEEVENTBUS._options = None
_REQUESTPOSTTOEVENTBUS.fields_by_name['id']._options = None
_REQUESTPOSTTOEVENTBUS.fields_by_name['destinations']._options = None
_REQUESTPOSTTOEVENTBUS.fields_by_name['message']._options = None
_REQUESTPOSTTOEVENTBUS._options = None
_UPDATEEVENTBUSDEVICECONNECTED.fields_by_name['id']._options = None
_UPDATEEVENTBUSDEVICECONNECTED.fields_by_name['user_id']._options = None
_UPDATEEVENTBUSDEVICECONNECTED.fields_by_name['device_id']._options = None
_UPDATEEVENTBUSDEVICECONNECTED.fields_by_name['peer']._options = None
_UPDATEEVENTBUSDEVICEDISCONNECTED.fields_by_name['id']._options = None
_UPDATEEVENTBUSDEVICEDISCONNECTED.fields_by_name['user_id']._options = None
_UPDATEEVENTBUSDEVICEDISCONNECTED.fields_by_name['device_id']._options = None
_UPDATEEVENTBUSDEVICEDISCONNECTED.fields_by_name['peer']._options = None
_UPDATEEVENTBUSMESSAGE.fields_by_name['id']._options = None
_UPDATEEVENTBUSMESSAGE.fields_by_name['sender_id']._options = None
_UPDATEEVENTBUSMESSAGE.fields_by_name['sender_device_id']._options = None
_UPDATEEVENTBUSMESSAGE.fields_by_name['message']._options = None
_UPDATEEVENTBUSDISPOSED.fields_by_name['id']._options = None

_EVENTBUS = _descriptor.ServiceDescriptor(
  name='EventBus',
  full_name='dialog.EventBus',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1143,
  serialized_end=1512,
  methods=[
  _descriptor.MethodDescriptor(
    name='JoinEventBus',
    full_name='dialog.EventBus.JoinEventBus',
    index=0,
    containing_service=None,
    input_type=_REQUESTJOINEVENTBUS,
    output_type=_RESPONSEJOINEVENTBUS,
    serialized_options=b'\202\323\344\223\002#\"\036/v1/grpc/EventBus/JoinEventBus:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KeepAliveEventBus',
    full_name='dialog.EventBus.KeepAliveEventBus',
    index=1,
    containing_service=None,
    input_type=_REQUESTKEEPALIVEEVENTBUS,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002(\"#/v1/grpc/EventBus/KeepAliveEventBus:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PostToEventBus',
    full_name='dialog.EventBus.PostToEventBus',
    index=2,
    containing_service=None,
    input_type=_REQUESTPOSTTOEVENTBUS,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002%\" /v1/grpc/EventBus/PostToEventBus:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EVENTBUS)

DESCRIPTOR.services_by_name['EventBus'] = _EVENTBUS

# @@protoc_insertion_point(module_scope)
